from bottle import get, post, run, HTTPError

@get("/")
def get_root():
    return {"status": "OK"}

@get("/long")
def get_long():
    return {"data": [
        {"name": "apple", "calories": 5},
        {"name": "orange", "calories": 120},
        {"name": "pear", "calories": 45},
    ]}

@post("/")
def post_root():
    return {"status": "SUCCESS"}

@get("/errors/404")
def error_404():
    raise HTTPError(404, body={"error": "no exist"})

@get("/errors/500")
def error_500():
    raise HTTPError(500, body={"error": "server error"})

run(host="localhost", port=8080)
